@@ -1,4 +1,4 @@
-<TeXmacs|1.99.6>
+<TeXmacs|1.99.10>
 
 <style|<tuple|source|std>>
 
@@ -29,11 +29,11 @@
 
   <assign|hflush|<macro|<htab|0fn|0>>>
 
-  <assign|right-flush|<macro|<htab|0fn|first>>>
+  <assign|right-flush|<macro|<specific|texmacs|<htab|0fn|first>>>>
 
   <assign|left-flush|<macro|<htab|0fn|last>>>
 
-  <assign|wide-normal|<macro|body|<surround|<no-indent>|<htab|0fn|first>|<arg|body>>>>
+  <assign|wide-normal|<macro|body|<surround|<no-indent>|<specific|texmacs|<htab|0fn|first>>|<arg|body>>>>
 
   <assign|wide-centered|<macro|body|<surround|<no-indent><htab|0fn|last>|<htab|0fn|first>|<arg|body>>>>
 
@@ -51,7 +51,7 @@
 
   <assign|large-padding-below|1fn>
 
-  <assign|padded-normal|<macro|before|after|body|<surround|<vspace*|<arg|before>><no-indent>|<htab|0fn|first><vspace|<arg|after>>|<arg|body>>>>
+  <assign|padded-normal|<macro|before|after|body|<surround|<vspace*|<arg|before>><no-indent>|<specific|texmacs|<htab|0fn|first>><vspace|<arg|after>>|<arg|body>>>>
 
   <assign|padded-centered|<macro|before|after|body|<surround|<vspace*|<arg|before>><no-indent><htab|0fn|last>|<htab|0fn|first><vspace|<arg|after>>|<arg|body>>>>
 
@@ -60,7 +60,7 @@
       <arg|title>
     </surround>
 
-    <\surround|<no-indent>|<htab|0fn|first><vspace|<arg|after>>>
+    <\surround|<no-indent>|<specific|texmacs|<htab|0fn|first>><vspace|<arg|after>>>
       <arg|body>
     </surround>
   </macro>>
@@ -83,6 +83,12 @@
     </padded-normal-titled|<arg|title>>
   </macro>>
 
+  <assign|padded-center|<macro|body|<with|par-mode|center|<surround|<vspace*|<value|padding-above>><no-indent>|<vspace|<value|padding-below>>|<arg|body>>>>>
+
+  <assign|padded-left-aligned|<macro|body|<with|par-mode|left|<surround|<vspace*|<value|padding-above>><no-indent>|<vspace|<value|padding-below>>|<arg|body>>>>>
+
+  <assign|padded-right-aligned|<macro|body|<with|par-mode|right|<surround|<vspace*|<value|padding-above>><no-indent>|<vspace|<value|padding-below>>|<arg|body>>>>>
+
   <\active*>
     <\src-comment>
       Helper macros for underlined/overlined block environments (work also
@@ -204,21 +210,23 @@
   </active*>
 
   <assign|ornamented|<\macro|body>
-    <padded|<\ornament>
-      <\surround||<right-flush>>
-        <arg|body>
-      </surround>
-    </ornament>>
+    <\padded>
+      <\decorated>
+        <\surround||<right-flush>>
+          <arg|body>
+        </surround>
+      </decorated>
+    </padded>
   </macro>>
 
   <assign|ornamented-titled|<\macro|body|title>
-    <padded|<\ornament>
-      <\surround||<right-flush>>
-        <arg|body>
-      </surround>
-    <|ornament>
-      <arg|title>
-    </ornament>>
+    <\padded>
+      <\decorated-titled|<arg|title>>
+        <\surround||<right-flush>>
+          <arg|body>
+        </surround>
+      </decorated-titled>
+    </padded>
   </macro>>
 
   <drd-props|ornamented-titled|arity|2|accessible|all>
@@ -235,6 +243,48 @@
     </with>
   </macro>>
 
+  <\active*>
+    <\src-comment>
+      Decorations based on ornaments.
+    </src-comment>
+  </active*>
+
+  <assign|ornament-render-title|<macro|body|<arg|body>>>
+
+  <assign|ornament-render-body|<macro|body|<arg|body>>>
+
+  \;
+
+  <assign|decorated-hook|<macro|body|<with|bg-color|<value|ornament-extra-color>|old-color|<value|color>|old-math-color|<value|math-color>|old-strong-color|<value|strong-color>|<ornament-render-title|<with|ornament-extra-color|<value|bg-color>|color|<value|old-color>|math-color|<value|old-math-color>|strong-color|<value|old-strong-color>|<with|bg-color|<value|ornament-color>|<ornament-render-body|<with|ornament-color|<value|bg-color>|<arg|body>>>>>>>>>
+
+  <assign|decorated-title|<macro|body|<ornament-render-title|<arg|body>>>>
+
+  <assign|decorated-body|<macro|body|<ornament-render-body|<arg|body>>>>
+
+  \;
+
+  <assign|decorated|<macro|body|<decorated-hook|<ornament|<decorated-body|<arg|body>>>>>>
+
+  <assign|decorated-block|<\macro|body>
+    <decorated-hook|<\ornament>
+      <\wide-normal>
+        <\decorated-body>
+          <arg|body>
+        </decorated-body>
+      </wide-normal>
+    </ornament>>
+  </macro>>
+
+  <assign|decorated-titled|<macro|name|body|<decorated-hook|<ornament|<decorated-body|<arg|body>>|<decorated-title|<arg|name>>>>>>
+
+  <assign|decorated-titled-block|<\macro|name|body>
+    <decorated-hook|<\ornament>
+      <\wide-normal>
+        <decorated-body|<arg|body>>
+      </wide-normal>
+    </ornament|<decorated-title|<arg|name>>>>
+  </macro>>
+
   <\active*>
     <\src-comment>
       Indentation.
@@ -313,6 +363,24 @@
 
   <assign|simple-page|<macro|<style-with|src-compact|none|<assign|page-this-header|><assign|page-this-footer|<no-indent><htab|5mm><page-number><htab|5mm>>>>>
 
+  <\active*>
+    <\src-comment>
+      Further table macros.
+    </src-comment>
+  </active*>
+
+  <assign|description-table|<macro|body|<tformat|<twith|table-width|1par>|<twith|table-hmode|exact>|<twith|table-block|yes>|<twith|table-min-cols|2>|<cwith|1|-1|2|-1|cell-hyphen|t>|<cwith|1|-1|1|-1|cell-hpart|0.001>|<cwith|1|-1|1|1|cell-lsep|0fn>|<cwith|1|-1|-1|-1|cell-rsep|0fn>|<cwith|1|-2|1|-1|cell-bsep|<value|par-par-sep>>|<cwith|2|-1|1|-1|cell-tsep|<value|par-sep>>|<arg|body>>>>
+
+  <assign|prefixed-line|<\macro|prefix|body>
+    <\with|par-first|0fn>
+      <\description-table>
+        <tformat|<twith|table-valign|T>|<twith|table-hmode|min>|<cwith|1|-1|1|-1|cell-lsep|0em>|<cwith|1|-1|1|-1|cell-rsep|0em>|<cwith|1|1|1|-1|cell-tsep|0em>|<cwith|-1|-1|1|-1|cell-bsep|0em>|<cwith|1|-1|1|-1|cell-vcorrect|n>|<table|<row|<cell|<arg|prefix>>|<\cell>
+          <arg|body>
+        </cell>>>>
+      </description-table>
+    </with>
+  </macro>>
+
   <\active*>
     <\src-comment>
       Other macros.
@@ -335,6 +403,12 @@
 
   <drd-props|semicolon-separated|arity|<tuple|repeat|1|1>|accessible|all>
 
+  <assign|prepend-space|<macro|x| <arg|x>>>
+
+  <assign|space-separated|<xmacro|items|<arg|items|0><map-args|prepend-space|concat|items|1>>>
+
+  <assign|document-bis|<xmacro|items|<map-args|identity|document|items>>>
+
   <assign|font-magnify|<macro|factor|body|<with|font-size|<times|<value|font-size>|<arg|factor>>|<arg|body>>>>
 
   <assign|hidden-title|<macro|title|>>
