@@ -732,10 +732,8 @@
         (with selection (selection-tree)
           (clipboard-cut "graphics background")
           (insert-go-to `(draw-over ,selection ,g "2cm") '(1 2 1))))
-      (with g `(with "gr-mode" (tuple "hand-edit" "line")
-                     "gr-geometry" (tuple "geometry" "4cm" "4cm" "center")
-                 (graphics))
-        (insert-go-to `(draw-over "" ,g "2cm") '(1 4 1)))))
+      (with g `(with "gr-mode" (tuple "hand-edit" "line") (graphics))
+        (insert-go-to `(draw-over "" ,g "2cm") '(1 2 1)))))
 
 (tm-define (make-anim l)
   (with duration "1s"
