@@ -119,6 +119,7 @@
   (not-in-session% (not (inside? 'session)))
   (in-math-in-session% #t in-math% in-session%)
   (in-math-not-in-session% #t in-math% not-in-session%)
+  (in-multicol-style% (!= (get-init "par-columns") "1"))
   (in-std% (style-has? "std-dtd"))
   (in-std-text% #t in-text% in-std%)
   (in-tmdoc% (style-has? "tmdoc-style"))
@@ -130,10 +131,19 @@
   (in-plugin-with-converters%
    (plugin-supports-math-input-ref (get-env "prog-language")))
   (in-screens% (inside? 'screens))
+  (in-beamer% (style-has? "beamer-style"))
+  (in-poster% (style-has? "poster-style"))
+  (in-edu% (style-has? "std-edu-dtd"))
+  (in-edu-text% #t in-text% in-edu%)
+  (in-edu-math% #t in-math% in-edu%)
   (with-any-selection% (selection-active-any?))
   (with-active-selection% (selection-active-normal?))
   (in-cpp% (== (get-env "prog-language") "cpp"))
   (in-prog-cpp% #t in-prog% in-cpp%)
+  (in-fortran% (== (get-env "prog-language") "fortran"))
+  (in-prog-fortran% #t in-prog% in-fortran%)
+  (in-scala% (== (get-env "prog-language") "scala"))
+  (in-prog-scala% #t in-prog% in-scala%)
   (in-scheme% (== (get-env "prog-language") "scheme"))
   (in-prog-scheme% #t in-prog% in-scheme%)
   (in-python% (== (get-env "prog-language") "python"))
@@ -213,6 +223,8 @@
   (like-std% (has-look-and-feel? "std"))
   (simple-menus% (== (get-preference "detailed menus") "simple"))
   (detailed-menus% (== (get-preference "detailed menus") "detailed"))
+  (window-per-buffer% (== (get-preference "buffer management") "separate"))
+  (buffers-share-window% (== (get-preference "buffer management") "share"))
   (with-database-tool% (== (get-preference "database tool") "on"))
   (with-debugging-tool% (== (get-preference "debugging tool") "on"))
   (with-developer-tool% (== (get-preference "developer tool") "on"))
@@ -223,15 +235,13 @@
   (with-versioning-tool% (== (get-preference "versioning tool") "on"))
   (in-presentation% (or (style-has? "beamer-style")
                         (== (get-preference "presentation tool") "on")
-                        (inside? 'screens)))
+                        (inside? 'screens)) in-beamer%)
   (search-mode% (== (get-input-mode) 1))
   (replace-mode% (== (get-input-mode) 2))
   (spell-mode% (== (get-input-mode) 3))
   (complete-mode% (== (get-input-mode) 4))
   (remote-control-mode% (== remote-control-flag? #t))
-  (in-cyrillic-cp1251% (cyrillic-input-method? "cp1251") in-cyrillic%)
   (in-cyrillic-jcuken% (cyrillic-input-method? "jcuken") in-cyrillic%)
-  (in-cyrillic-koi8% (cyrillic-input-method? "koi8") in-cyrillic%)
   (in-cyrillic-translit% (cyrillic-input-method? "translit") in-cyrillic%)
   (in-cyrillic-yawerty% (cyrillic-input-method? "yawerty") in-cyrillic%))
 
