@@ -152,9 +152,9 @@
       ---)
   ("Exercise" (make 'exercise))
   ("Problem" (make 'problem))
-  ("Solution" (make 'solution))
   ("Question" (make 'question))
-  ("Answer" (make 'answer)))
+  ("Solution" (make 'solution*))
+  ("Answer" (make 'answer*)))
 
 (menu-bind prominent-menu
   ("Quote" (make 'quote-env))
@@ -163,11 +163,17 @@
   ---
   ("Indent" (make 'indent))
   ("Jump in" (make 'jump-in))
-  ("Compact" (make 'compact))
   ---
-  ("Centered" (make 'center))
-  ("Left aligned" (make 'left-aligned))
-  ("Right aligned" (make 'right-aligned))
+  ("Centered" (make 'padded-center))
+  ("Left aligned" (make 'padded-left-aligned))
+  ("Right aligned" (make 'padded-right-aligned))
+  (with s (get-env "par-par-sep")
+    (assuming (and (not (string-ends? s "fns"))
+                   (not (string-starts? s "0fn")))
+      ---
+      ("Compact" (make 'compact))
+      ("Compressed" (make 'compressed))
+      ("Amplified" (make 'amplified))))
   ---
   ("Padded" (make 'padded))
   ("Overlined" (make 'overlined))
@@ -189,10 +195,12 @@
   ("Pseudo code" (make 'render-code))
   ---
   ("Indent" (make 'indent))
-  ("Tabbed" (make 'tabbed))
+  (when (not (selection-active?))
+    ("Tabbed" (make 'wide-tabbed)))
   ---
   (-> "Inline code"
       ("C++" (make 'cpp))
+      ("Fortran" (make 'fortran))
       ("Mathemagix" (make 'mmx))
       ("Python" (make 'python))
       ("R" (make 'r))
@@ -203,6 +211,7 @@
       ("Verbatim" (make 'verbatim)))
   (-> "Block of code"
       ("C++" (make 'cpp-code))
+      ("Fortran" (make 'fortran-code))
       ("Mathemagix" (make 'mmx-code))
       ("Python" (make 'python-code))
       ("R" (make 'r-code))
@@ -218,17 +227,28 @@
 
 (menu-bind note-menu
   (when (not (or (inside? 'float) (inside? 'footnote)))
-    ("Footnote" (make 'footnote))
-    ("Marginal note" (make-marginal-note))
+    ("Footnote" (make-wrapped 'footnote))
+    (when (not (selection-active-non-small?))
+      ("Marginal note" (make-marginal-note)))
     ;;("Balloon" (make-balloon))
     ---
     ("Floating object" (make-insertion "float"))
-    ("Floating phantom" (insert '(phantom-float "float" "hf")))
-    ("Floating figure" (begin (make-insertion "float") (make 'big-figure)))
-    ("Floating table" (begin (make-insertion "float")
-                             (insert-go-to '(big-table "" "") '(0 0))
-                             (make 'tabular)))
-    ("Floating algorithm" (begin (make-insertion "float") (make 'algorithm)))))
+    (when (not (selection-active-non-small?))
+      ("Floating phantom" (insert '(phantom-float "float" "hf"))))
+    (when (not (selection-active-non-small?))
+      ("Floating figure"
+       (wrap-selection-small
+         (make-insertion "float")
+         (insert-go-to '(big-figure "" (document "")) '(0 0))))
+      ("Floating table"
+       (wrap-selection-small
+         (make-insertion "float")
+         (insert-go-to '(big-table "" (document "")) '(0 0))
+         (make 'tabular))))
+    ("Floating algorithm"
+     (wrap-selection-any
+       (make-insertion "float")
+       (make 'algorithm)))))
 
 (menu-bind position-marginal-note-menu
   (group "Horizontal position")
@@ -325,7 +345,8 @@
   ("Name" (make 'name))
   ("Person" (make 'person))
   ("Cite" (make 'cite*))
-  ("Abbreviation" (make 'abbr))
+  (when (not (selection-active-non-small?))
+    ("Abbreviation" (make 'abbr)))
   ("Acronym" (make 'acronym))
   ---
   ("Verbatim" (make 'verbatim))
@@ -428,6 +449,11 @@
   ("Long" (make-tmlist 'description-long))
   ("Paragraphs" (make-tmlist 'description-paragraphs)))
 
+(menu-bind lists-menu
+  (-> "Itemize" (link itemize-menu))
+  (-> "Enumerate" (link enumerate-menu))
+  (-> "Description" (link description-menu)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Automatically generated content
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -480,9 +506,9 @@
       (-> "Automatic" (link automatic-menu)))
   (if (style-has? "std-list-dtd")
       ---
-      (-> "Itemize" (link itemize-menu))
-      (-> "Enumerate" (link enumerate-menu))
-      (-> "Description" (link description-menu))))
+      (link lists-menu)))
+
+(menu-bind text-extra-menu)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Text menus for inserting inline content
@@ -503,6 +529,7 @@
 
 (menu-bind text-menu
   (link text-block-menu)
+  (link text-extra-menu)
   ---
   (link text-inline-menu)
   ---
@@ -559,6 +586,8 @@
                    "Insert automatically generated content")
           (link automatic-menu))))
 
+(menu-bind text-extra-icons)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Icons for modifying text properties
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -619,14 +648,15 @@
   ;;("Goedenmiddag" (display* "Hi there\n"))
   ;;(mini #t (input (display* answer "\n") "string" '("Hello" "Bonjour") "0.5w"))
   (link text-block-icons)
+  (link text-extra-icons)
   (if (style-has? "std-markup-dtd")
       /)
   (link text-inline-icons)
   (if (in-manual?) (link tmdoc-icons))
   (link texmacs-insert-icons)
   (if (and (in-presentation?) (not (visible-icon-bar? 0)))
-    /
-    (link dynamic-icons)))
+      /
+      (link dynamic-icons)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menus for entering title information
